All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] apparmor: fix spelling mistake: "resoure" -> "resource"
@ 2017-08-24  8:31 ` Colin King
  0 siblings, 0 replies; 4+ messages in thread
From: Colin King @ 2017-08-24  8:31 UTC (permalink / raw)
  To: John Johansen, James Morris, Serge E . Hallyn, linux-security-module
  Cc: linux-kernel

From: Colin Ian King <colin.king@canonical.com>

Trivial fix to spelling mistake in comment and also with text in
audit_resource call.

Signed-off-by: Colin Ian King <colin.king@canonical.com>
---
 security/apparmor/resource.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/security/apparmor/resource.c b/security/apparmor/resource.c
index d8bc842594ed..cf4d234febe9 100644
--- a/security/apparmor/resource.c
+++ b/security/apparmor/resource.c
@@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
 /**
  * audit_resource - audit setting resource limit
  * @profile: profile being enforced  (NOT NULL)
  * @resoure: rlimit being auditing
  * @value: value being set
  * @error: error value
  *
@@ -128,7 +128,7 @@ int aa_task_setrlimit(struct aa_label *label, struct task_struct *task,
 		error = fn_for_each(label, profile,
 				audit_resource(profile, resource,
 					       new_rlim->rlim_max, peer,
-					       "cap_sys_resoure", -EACCES));
+					       "cap_sys_resource", -EACCES));
 	else
 		error = fn_for_each_confined(label, profile,
 				profile_setrlimit(profile, resource, new_rlim));
@@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
  * audit_resource - audit setting resource limit
  * @profile: profile being enforced  (NOT NULL)
- * @resoure: rlimit being auditing
+ * @resource: rlimit being auditing
  * @value: value being set
  * @error: error value
-- 
2.14.1

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* [PATCH] apparmor: fix spelling mistake: "resoure" -> "resource"
@ 2017-08-24  8:31 ` Colin King
  0 siblings, 0 replies; 4+ messages in thread
From: Colin King @ 2017-08-24  8:31 UTC (permalink / raw)
  To: linux-security-module

From: Colin Ian King <colin.king@canonical.com>

Trivial fix to spelling mistake in comment and also with text in
audit_resource call.

Signed-off-by: Colin Ian King <colin.king@canonical.com>
---
 security/apparmor/resource.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/security/apparmor/resource.c b/security/apparmor/resource.c
index d8bc842594ed..cf4d234febe9 100644
--- a/security/apparmor/resource.c
+++ b/security/apparmor/resource.c
@@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
 /**
  * audit_resource - audit setting resource limit
  * @profile: profile being enforced  (NOT NULL)
  * @resoure: rlimit being auditing
  * @value: value being set
  * @error: error value
  *
@@ -128,7 +128,7 @@ int aa_task_setrlimit(struct aa_label *label, struct task_struct *task,
 		error = fn_for_each(label, profile,
 				audit_resource(profile, resource,
 					       new_rlim->rlim_max, peer,
-					       "cap_sys_resoure", -EACCES));
+					       "cap_sys_resource", -EACCES));
 	else
 		error = fn_for_each_confined(label, profile,
 				profile_setrlimit(profile, resource, new_rlim));
@@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
  * audit_resource - audit setting resource limit
  * @profile: profile being enforced  (NOT NULL)
- * @resoure: rlimit being auditing
+ * @resource: rlimit being auditing
  * @value: value being set
  * @error: error value
-- 
2.14.1

--
To unsubscribe from this list: send the line "unsubscribe linux-security-module" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [PATCH] apparmor: fix spelling mistake: "resoure" -> "resource"
  2017-08-24  8:31 ` Colin King
@ 2017-09-25 14:24   ` John Johansen
  -1 siblings, 0 replies; 4+ messages in thread
From: John Johansen @ 2017-09-25 14:24 UTC (permalink / raw)
  To: Colin King, James Morris, Serge E . Hallyn, linux-security-module
  Cc: linux-kernel

On 08/24/2017 04:31 AM, Colin King wrote:
> From: Colin Ian King <colin.king@canonical.com>
> 
> Trivial fix to spelling mistake in comment and also with text in
> audit_resource call.
> 
> Signed-off-by: Colin Ian King <colin.king@canonical.com>
> ---
>  security/apparmor/resource.c | 4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)
> 
> diff --git a/security/apparmor/resource.c b/security/apparmor/resource.c
> index d8bc842594ed..cf4d234febe9 100644
> --- a/security/apparmor/resource.c
> +++ b/security/apparmor/resource.c
> @@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
>  /**
>   * audit_resource - audit setting resource limit
>   * @profile: profile being enforced  (NOT NULL)
> - * @resoure: rlimit being auditing
> + * @resource: rlimit being auditing
>   * @value: value being set
>   * @error: error value
>   *
> @@ -128,7 +128,7 @@ int aa_task_setrlimit(struct aa_label *label, struct task_struct *task,
>  		error = fn_for_each(label, profile,
>  				audit_resource(profile, resource,
>  					       new_rlim->rlim_max, peer,
> -					       "cap_sys_resoure", -EACCES));
> +					       "cap_sys_resource", -EACCES));
>  	else
>  		error = fn_for_each_confined(label, profile,
>  				profile_setrlimit(profile, resource, new_rlim));
> 


pulled in to apparmor-next

^ permalink raw reply	[flat|nested] 4+ messages in thread

* [PATCH] apparmor: fix spelling mistake: "resoure" -> "resource"
@ 2017-09-25 14:24   ` John Johansen
  0 siblings, 0 replies; 4+ messages in thread
From: John Johansen @ 2017-09-25 14:24 UTC (permalink / raw)
  To: linux-security-module

On 08/24/2017 04:31 AM, Colin King wrote:
> From: Colin Ian King <colin.king@canonical.com>
> 
> Trivial fix to spelling mistake in comment and also with text in
> audit_resource call.
> 
> Signed-off-by: Colin Ian King <colin.king@canonical.com>
> ---
>  security/apparmor/resource.c | 4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)
> 
> diff --git a/security/apparmor/resource.c b/security/apparmor/resource.c
> index d8bc842594ed..cf4d234febe9 100644
> --- a/security/apparmor/resource.c
> +++ b/security/apparmor/resource.c
> @@ -47,7 +47,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
>  /**
>   * audit_resource - audit setting resource limit
>   * @profile: profile being enforced  (NOT NULL)
> - * @resoure: rlimit being auditing
> + * @resource: rlimit being auditing
>   * @value: value being set
>   * @error: error value
>   *
> @@ -128,7 +128,7 @@ int aa_task_setrlimit(struct aa_label *label, struct task_struct *task,
>  		error = fn_for_each(label, profile,
>  				audit_resource(profile, resource,
>  					       new_rlim->rlim_max, peer,
> -					       "cap_sys_resoure", -EACCES));
> +					       "cap_sys_resource", -EACCES));
>  	else
>  		error = fn_for_each_confined(label, profile,
>  				profile_setrlimit(profile, resource, new_rlim));
> 


pulled in to apparmor-next
--
To unsubscribe from this list: send the line "unsubscribe linux-security-module" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2017-09-25 14:24 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2017-08-24  8:31 [PATCH] apparmor: fix spelling mistake: "resoure" -> "resource" Colin King
2017-08-24  8:31 ` Colin King
2017-09-25 14:24 ` John Johansen
2017-09-25 14:24   ` John Johansen

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.